@@ -30,12 +30,23 @@ import shutil
 import site
 import sys
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Callable, TextIO
+from typing import TYPE_CHECKING, Any, TextIO
 
 from ansible_compat.prerun import get_cache_dir
 from filelock import FileLock, Timeout
 from rich.markup import escape
 
+from ansiblelint.constants import RC, SKIP_SCHEMA_UPDATE
+
+# safety check for broken ansible core, needs to happen first
+try:
+    # pylint: disable=unused-import
+    from ansible.parsing.dataloader import DataLoader  # noqa: F401
+
+except Exception as _exc:  # pylint: disable=broad-exception-caught # noqa: BLE001
+    logging.fatal(_exc)
+    sys.exit(RC.INVALID_CONFIG)
+# pylint: disable=ungrouped-imports
 from ansiblelint import cli
 from ansiblelint._mockings import _perform_mockings_cleanup
 from ansiblelint.app import get_app
@@ -53,7 +64,6 @@ from ansiblelint.config import (
     log_entries,
     options,
 )
-from ansiblelint.constants import RC, SKIP_SCHEMA_UPDATE
 from ansiblelint.loaders import load_ignore_txt
 from ansiblelint.runner import get_matches
 from ansiblelint.skip_utils import normalize_tag
@@ -62,12 +72,13 @@ from ansiblelint.version import __version__
 if TYPE_CHECKING:
     # RulesCollection must be imported lazily or ansible gets imported too early.
 
+    from collections.abc import Callable
+
     from ansiblelint.rules import RulesCollection
     from ansiblelint.runner import LintResult
 
 
 _logger = logging.getLogger(__name__)
-cache_dir_lock: None | FileLock = None
 
 
 class LintLogHandler(logging.Handler):
@@ -108,8 +119,9 @@ def initialize_logger(level: int = 0) -> None:
     _logger.debug("Logging initialized to level %s", logging_level)
 
 
-def initialize_options(arguments: list[str] | None = None) -> None:
+def initialize_options(arguments: list[str] | None = None) -> None | FileLock:
     """Load config options and store them inside options module."""
+    cache_dir_lock = None
     new_options = cli.get_config(arguments or [])
     new_options.cwd = pathlib.Path.cwd()
 
@@ -133,13 +145,13 @@ def initialize_options(arguments: list[str] | None = None) -> None:
         options.cache_dir.mkdir(parents=True, exist_ok=True)
 
     if not options.offline:  # pragma: no cover
-        cache_dir_lock = FileLock(  # pylint: disable=redefined-outer-name
+        cache_dir_lock = FileLock(
             f"{options.cache_dir}/.lock",
         )
         try:
             cache_dir_lock.acquire(timeout=180)
         except Timeout:  # pragma: no cover
-            _logger.error(
+            _logger.error(  # noqa: TRY400
                 "Timeout waiting for another instance of ansible-lint to release the lock.",
             )
             sys.exit(RC.LOCK_TIMEOUT)
@@ -148,6 +160,8 @@ def initialize_options(arguments: list[str] | None = None) -> None:
     if "ANSIBLE_DEVEL_WARNING" not in os.environ:  # pragma: no branch
         os.environ["ANSIBLE_DEVEL_WARNING"] = "false"
 
+    return cache_dir_lock
+
 
 def _do_list(rules: RulesCollection) -> int:
     # On purpose lazy-imports to avoid pre-loading Ansible
@@ -195,12 +209,6 @@ def _do_transform(result: LintResult, opts: Options) -> None:
 
 def support_banner() -> None:
     """Display support banner when running on unsupported platform."""
-    if sys.version_info < (3, 9, 0):  # pragma: no cover # noqa: UP036
-        prefix = "::warning::" if "GITHUB_ACTION" in os.environ else "WARNING: "
-        console_stderr.print(
-            f"{prefix}ansible-lint is no longer tested under Python {sys.version_info.major}.{sys.version_info.minor} and will soon require 3.9. Do not report bugs for this version.",
-            style="bold red",
-        )
 
 
 def fix(runtime_options: Options, result: LintResult, rules: RulesCollection) -> None:
@@ -275,11 +283,11 @@ def fix(runtime_options: Options, result: LintResult, rules: RulesCollection) ->
 def main(argv: list[str] | None = None) -> int:
     """Linter CLI entry point."""
     # alter PATH if needed (venv support)
-    path_inject()
+    path_inject(argv[0] if argv and argv[0] else "")
 
     if argv is None:  # pragma: no cover
         argv = sys.argv
-    initialize_options(argv[1:])
+    cache_dir_lock = initialize_options(argv[1:])
 
     console_options["force_terminal"] = options.colored
     reconfigure(console_options)
@@ -318,6 +326,7 @@ def main(argv: list[str] | None = None) -> int:
             ),
         )
         or options.offline
+        or options.nodeps
     )
 
     if not skip_schema_update:
@@ -364,7 +373,15 @@ def main(argv: list[str] | None = None) -> int:
             match.ignored = True
             _logger.debug("Ignored: %s", match)
 
+    if app.yamllint_config.incompatible:
+        logging.log(
+            level=logging.ERROR if options.write_list else logging.WARNING,
+            msg=app.yamllint_config.incompatible,
+        )
+
     if options.write_list:
+        if app.yamllint_config.incompatible:
+            sys.exit(RC.INVALID_CONFIG)
         fix(runtime_options=options, result=result, rules=rules)
 
     app.render_matches(result.matches)
@@ -399,7 +416,7 @@ def _run_cli_entrypoint() -> None:
         raise SystemExit(exc) from exc
 
 
-def path_inject() -> None:
+def path_inject(own_location: str = "") -> None:
     """Add python interpreter path to top of PATH to fix outside venv calling."""
     # This make it possible to call ansible-lint that was installed inside a
     # virtualenv without having to pre-activate it. Otherwise subprocess will
@@ -440,8 +457,15 @@ def path_inject() -> None:
     ):
         inject_paths.append(str(py_path))
 
+    # last option, if nothing else is found, just look next to ourselves...
+    if own_location:
+        own_location = os.path.realpath(own_location)
+        parent = Path(own_location).parent
+        if (parent / "ansible").exists() and str(parent) not in paths:
+            inject_paths.append(str(parent))
+
     if not os.environ.get("PYENV_VIRTUAL_ENV", None):
-        if inject_paths:
+        if inject_paths and not all("pipx" in p for p in inject_paths):
             print(  # noqa: T201
                 f"WARNING: PATH altered to include {', '.join(inject_paths)} :: This is usually a sign of broken local setup, which can cause unexpected behaviors.",
                 file=sys.stderr,
