@@ -1,4 +1,5 @@
 """Output formatters."""
+
 from __future__ import annotations
 
 import hashlib
@@ -28,6 +29,7 @@ class BaseFormatter(Generic[T]):
     ----
         base_dir (str|Path): reference directory against which display relative path.
         display_relative_path (bool): whether to show path as relative or absolute
+
     """
 
     def __init__(self, base_dir: str | Path, display_relative_path: bool) -> None:
@@ -144,7 +146,7 @@ class CodeclimateJSONFormatter(BaseFormatter[Any]):
         """Format a list of match errors as a JSON string."""
         if not isinstance(matches, list):
             msg = f"The {self.__class__} was expecting a list of MatchError."
-            raise RuntimeError(msg)
+            raise TypeError(msg)
 
         result = []
         for match in matches:
@@ -211,7 +213,7 @@ class SarifFormatter(BaseFormatter[Any]):
         """Format a list of match errors as a JSON string."""
         if not isinstance(matches, list):
             msg = f"The {self.__class__} was expecting a list of MatchError."
-            raise RuntimeError(msg)
+            raise TypeError(msg)
 
         root_path = Path(str(self.base_dir)).as_uri()
         root_path = root_path + "/" if not root_path.endswith("/") else root_path
@@ -288,9 +290,9 @@ class SarifFormatter(BaseFormatter[Any]):
             "ruleId": match.tag,
             "level": self.get_sarif_result_severity_level(match),
             "message": {
-                "text": str(match.details)
-                if str(match.details)
-                else str(match.message),
+                "text": (
+                    str(match.details) if str(match.details) else str(match.message)
+                ),
             },
             "locations": [
                 {
