@@ -1,4 +1,5 @@
 """Implementation of GalaxyRule."""
+
 from __future__ import annotations
 
 import sys
@@ -40,6 +41,7 @@ class GalaxyRule(AnsibleLintRule):
             "application",
             "cloud",
             "database",
+            "eda",
             "infrastructure",
             "linux",
             "monitoring",
@@ -56,6 +58,7 @@ class GalaxyRule(AnsibleLintRule):
         changelog_found = 0
         changelog_paths = [
             base_path / "changelogs" / "changelog.yaml",
+            base_path / "changelogs" / "changelog.yml",
             base_path / "CHANGELOG.rst",
             base_path / "CHANGELOG.md",
         ]
@@ -63,8 +66,8 @@ class GalaxyRule(AnsibleLintRule):
         for path in changelog_paths:
             if path.is_file():
                 changelog_found = 1
-        galaxy_tag_list = data.get("tags", None)
-        collection_deps = data.get("dependencies", None)
+        galaxy_tag_list = data.get("tags")
+        collection_deps = data.get("dependencies")
         if collection_deps:
             for dep, ver in collection_deps.items():
                 if (
@@ -167,7 +170,7 @@ class Version:
 def _coerce(other: object) -> Version:
     if isinstance(other, str):
         other = Version(other)
-    if isinstance(other, (int, float)):
+    if isinstance(other, int | float):
         other = Version(str(other))
     if isinstance(other, Version):
         return other
